@@ -1,5 +1,6 @@
 import inspect
 import re
+from os import getenv
 from typing import Dict, List, Optional, Union
 
 import click
@@ -63,8 +64,9 @@ STYLE_ERRORS_PANEL_BORDER = "red"
 ALIGN_ERRORS_PANEL = "left"
 STYLE_ERRORS_SUGGESTION = "dim"
 STYLE_ABORTED = "red"
-MAX_WIDTH: Optional[int] = None  # Set to an int to limit to that many characters
+MAX_WIDTH = int(getenv("TERMINAL_WIDTH")) if getenv("TERMINAL_WIDTH") else None  # type: ignore
 COLOR_SYSTEM = "auto"  # Set to None to disable colors
+FORCE_TERMINAL = True if getenv("GITHUB_ACTIONS") or getenv("FORCE_COLOR") or getenv("PY_COLORS") else None
 
 # Fixed strings
 HEADER_TEXT: Optional[str] = None
@@ -89,6 +91,7 @@ SHOW_ARGUMENTS = False  # Show positional arguments
 SHOW_METAVARS_COLUMN = True  # Show a column with the option metavar (eg. INTEGER)
 APPEND_METAVARS_HELP = False  # Append metavar (eg. [TEXT]) after the help text
 GROUP_ARGUMENTS_OPTIONS = False  # Show arguments with options instead of in own panel
+OPTION_ENVVAR_FIRST = False  # Show env vars before option help text instead of avert
 USE_MARKDOWN = False  # Parse help strings as markdown
 USE_MARKDOWN_EMOJI = True  # Parse emoji codes in markdown :smile:
 USE_RICH_MARKUP = False  # Parse help strings for rich markup (eg. [red]my text[/])
@@ -127,6 +130,8 @@ def _get_rich_console() -> Console:
         ),
         highlighter=highlighter,
         color_system=COLOR_SYSTEM,
+        force_terminal=FORCE_TERMINAL,
+        width=MAX_WIDTH,
     )
 
 
@@ -224,6 +229,24 @@ def _get_parameter_help(param: Union[click.Option, click.Argument], ctx: click.C
     """
     items = []
 
+    # Get the environment variable first
+    envvar = getattr(param, "envvar", None)
+    # https://github.com/pallets/click/blob/0aec1168ac591e159baf6f61026d6ae322c53aaf/src/click/core.py#L2720-L2726
+    if envvar is None:
+        if (
+            getattr(param, "allow_from_autoenv", None)
+            and getattr(ctx, "auto_envvar_prefix", None) is not None
+            and param.name is not None
+        ):
+            envvar = f"{ctx.auto_envvar_prefix}_{param.name.upper()}"
+    if envvar is not None:
+        envvar = ", ".join(param.envvar) if type(envvar) is list else envvar
+
+    # Environment variable BEFORE help text
+    if getattr(param, "show_envvar", None) and OPTION_ENVVAR_FIRST:
+        items.append(Text(ENVVAR_STRING.format(envvar), style=STYLE_OPTION_ENVVAR))
+
+    # Main help text
     if getattr(param, "help", None):
         paragraphs = param.help.split("\n\n")
         # Remove single linebreaks
@@ -251,22 +274,9 @@ def _get_parameter_help(param: Union[click.Option, click.Argument], ctx: click.C
                 )
             )
 
-    # Environment variable
-    if getattr(param, "show_envvar", None):
-        envvar = getattr(param, "envvar", None)
-
-        # https://github.com/pallets/click/blob/0aec1168ac591e159baf6f61026d6ae322c53aaf/src/click/core.py#L2720-L2726
-        if envvar is None:
-            if (
-                getattr(param, "allow_from_autoenv", None)
-                and getattr(ctx, "auto_envvar_prefix", None) is not None
-                and param.name is not None
-            ):
-                envvar = f"{ctx.auto_envvar_prefix}_{param.name.upper()}"
-
-        if envvar is not None:
-            envvar = ", ".join(param.envvar) if type(envvar) is list else envvar
-            items.append(Text(ENVVAR_STRING.format(envvar), style=STYLE_OPTION_ENVVAR))
+    # Environment variable AFTER help text
+    if getattr(param, "show_envvar", None) and not OPTION_ENVVAR_FIRST:
+        items.append(Text(ENVVAR_STRING.format(envvar), style=STYLE_OPTION_ENVVAR))
 
     # Default value
     if getattr(param, "show_default", None):
@@ -350,10 +360,10 @@ def rich_format_help(
     # Print command / group help if we have some
     if obj.help:
 
-        # Print with a max width and some padding
+        # Print with some padding
         console.print(
             Padding(
-                Align(_get_help_text(obj), width=MAX_WIDTH, pad=False),
+                Align(_get_help_text(obj), pad=False),
                 (0, 1, 1, 1),
             )
         )
@@ -515,7 +525,6 @@ def rich_format_help(
                     border_style=STYLE_OPTIONS_PANEL_BORDER,
                     title=option_group.get("name", OPTIONS_PANEL_TITLE),
                     title_align=ALIGN_OPTIONS_PANEL,
-                    width=MAX_WIDTH,
                 )
             )
 
@@ -580,7 +589,6 @@ def rich_format_help(
                         border_style=STYLE_COMMANDS_PANEL_BORDER,
                         title=cmd_group.get("name", COMMANDS_PANEL_TITLE),
                         title_align=ALIGN_COMMANDS_PANEL,
-                        width=MAX_WIDTH,
                     )
                 )
 
@@ -589,7 +597,7 @@ def rich_format_help(
         # Remove single linebreaks, replace double with single
         lines = obj.epilog.split("\n\n")
         epilogue = "\n".join([x.replace("\n", " ").strip() for x in lines])
-        console.print(Padding(Align(highlighter(epilogue), width=MAX_WIDTH, pad=False), 1))
+        console.print(Padding(Align(highlighter(epilogue), pad=False), 1))
 
     # Footer text if we have it
     if FOOTER_TEXT:
@@ -628,7 +636,6 @@ def rich_format_error(self: click.ClickException):
             border_style=STYLE_ERRORS_PANEL_BORDER,
             title=ERRORS_PANEL_TITLE,
             title_align=ALIGN_ERRORS_PANEL,
-            width=MAX_WIDTH,
         )
     )
     if ERRORS_EPILOGUE:
